# This program generates a plot for the graphical solution of the finite square
# well potential with E<Vo. Below, we have a sketch of finite square well
# potential system (E<V0).
#
# __________            ___________ V0
#           |          |
# __________|__________|___________ E
#           |          |
#           |          |
# __________|__________|___________ x
#         -a/2        a/2
#
# This program uses the following libraries: matplotlib and numpy.
#
# Dr. Walter F. de Azevedo Jr.
# https://azevedolab.net/
# Porto Alegre, April 20, 2019

# Import libraries
import matplotlib.pyplot as plt
import numpy as np

# Define radius in Epsilon units for f2 = sqrt(R**2 - epsilon**2)
R = 4

# f1 = epsilon*tan(epsilon), tan(epsilon) = 0 for epsilon = 0,pi,2*pi,3*pi,...
# Calculate n (number of tangents plots inside the quarter of a circle)
n = int(R//np.pi)

# Looping through n
for i in range(n+1):

    # Define epsilon1 range with linspace
    epsilon1 = np.linspace(i*np.pi,(i+0.49999)*np.pi,1000)

    # Define first function f1 = epsilon*tan(epsilon)
    f1 = epsilon1*np.tan(epsilon1)

    # Create a plot of the f1 function
    plt.plot(epsilon1,f1)

# Define epsilon2 range with linspace
epsilon2 = np.linspace(0.01,R,1000)

# Define second function f2 = sqrt(R**2 - epsilon**2)
f2 = (R**2 - epsilon2**2)**(0.5)

# Create a plot of the f2 function
plt.plot(epsilon2,f2)

# Set up x-axis limits
plt.xlim(0.0,R)

# Set up y-axis limits
plt.ylim(0.0,R)

# Set up grid
plt.grid(True)

# Add labels
plt.xlabel('$\epsilon$',fontsize=20)

# Add title
plt.title('Graphical solution of the finite square well potential (E<Vo)')

# Show plot
plt.show()

# Save plot on png file
plt.savefig("graphical_solution_square_well_potential.png")